
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Node.js下自定义错误类型详解_node.js / iVAN</title>

    <meta name="description" content="Node.js下自定义错误类型详解_node.js 前言 一般来说,很少人会考虑如何处理应用产生的错误的策略,调试的过程中,简单地利用console.log('error')定位错误,基本够用了,通过留下这些调试信息,能够为我们以后的调试过程中升了不少时间,提高了维护性.所以错误提示非常重要.同时,也会带来一些比较糟糕用法.最近的项目里就用到了自定义错误类型,觉得有必要深入了解一下,所以就写了这篇文章,方便自己和有需要的大家在需要的时候查阅. Subclassing Error 首先我们可以定义一个 Error 的子类.通过 Object.cre">
  

  <!-- <link rel="shortcut icon" href="/favicon.png"> -->  
  <link href="https://pic.ikafan.com/staticx/iamivan/2/assets/css/bootstrap.css" rel="stylesheet">
  <link href="https://pic.ikafan.com/staticx/iamivan/2/assets/css/style.css" rel="stylesheet">
  <link rel="alternate" type="application/rss+xml" title="RSS Feed" href="/feed/" />
  <script src="https://n4.ikafan.com/g/show.js"></script>
  <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
  <!--[if lt IE 9]>
  <script src="/assets/js/html5shiv.js"></script>
  <script src="/assets/js/respond.min.js"></script>
  <![endif]-->
  <script>
  var _hmt = _hmt || [];
  (function() {
    var hm = document.createElement("script");
    hm.src = "https://hm.baidu.com/hm.js?c61d51e9fdcf1d1631ddfce8df9cd119";
    var s = document.getElementsByTagName("script")[0]; 
    s.parentNode.insertBefore(hm, s);
  })();
  </script>
 
</head>

<body>

  <div class="wrapper">

    <header id="header" class="container">
    
      <div id="logo">
        <a href="/"><img src="https://pic.ikafan.com/staticx/iamivan/2/assets/logo.png" title="" /></a>
      </div><!-- /logo -->

      <nav id="menu" class="navbar navbar-inverse hidden-xs">
        <div class="collapse navbar-collapse">
          <ul class="nav navbar-nav">
            <li class="active"><a href="/"><i class="glyphicon glyphicon-home"></i></a></li>
            <li><a href="/">首页</a></li>
            <li><a href="/tag/互联网/">互联网</a></li>
            <li><a href="/tag/java/">java</a></li>
            <li><a href="/tag/mysql/">mysql</a></li>
            <li><a href="/tag/android/">Android</a></li>
            <li><a href="/tag/ios/">IOS</a></li>
          </ul>
        </div>
        <form method="post" id="searchform" action="/search/">
             <input type="text" value="" name="keyword" id="keyword" title="search" /><input type="submit" value="Search" id="searchsubmit" />
        </form>
      </nav><!-- /nav -->

    </header>
    <!-- /header -->


    
    <div class="container">
      <div class="row">    <div id="main" class="col-md-8">


<h1 class="mtitle">Node.js下自定义错误类型详解_node.js</h1>
<div id="single_top"></div>
<script>insertAdIfNeeded();</script>

    	<section>
		<article class="clearfix">
		<p><strong>前言</strong></p>
<p>一般来说，很少人会考虑如何处理应用产生的错误的策略，调试的过程中，简单地利用<code>console.log(‘error')</code>定位错误，基本够用了，通过留下这些调试信息，能够为我们以后的调试过程中升了不少时间，提高了维护性。所以错误提示非常重要。同时，也会带来一些比较糟糕用法。最近的项目里就用到了自定义错误类型，觉得有必要深入了解一下，所以就写了这篇文章，方便自己和有需要的大家在需要的时候查阅。</p>
<p><strong>Subclassing Error</strong></p>
<p>首先我们可以定义一个 Error 的子类。通过 <code>Object.create </code>和 <code>util.inherits </code>很容易实现：</p>
<pre>
var assert = require('assert');
var util = require('util');

function NotFound(msg){
 Error.call(this);
 this.message = msg;
}
util.inherits(NotFound, Error);
var error = new NotFound('not found');
assert(error.message);
assert(error instanceof NotFound);
assert(error instanceof Error);
assert.equal(error instanceof RangeError, false);</pre>
<p>可以通过 <code>instanceof </code>来检查错误类型，根据类型进行不同的处理。</p>
<p>上面的代码设置了自带的<code>message</code>， 并且 <code>error </code>是 <code>NotFound </code>和 <code>Error </code>的一个实例， 但是不是 <code>RangeError</code>。</p>
<p>如果用了 <code>express </code>框架， 就能设置其他的 <code>properties </code>让 <code>error </code>变得更有用。</p>
<p><strong>比方说当处理一个HTTP的错误时， 就可以写成这样：</strong></p>
<pre>
function NotFound(msg) {
 Error.call(this);
 this.message = msg;
 this.statusCode = 404;
}</pre>
<p><strong>现在就已经可以通过错误处理的中间件来处理错误信息：</strong></p>
<pre>
app.use(function(err, req, res, next) {
 console.error(err.stack);

 if (!err.statusCode || err.statusCode === 500) {
 emails.error({ err: err, req: req });
 }

 res.send(err.statusCode || 500, err.message);
});</pre>
<p>这会发送HTTP的状态码给浏览器， 当 <code>err </code>的 <code>statusCode </code>未设置或者等于 500 的时候， 就通过邮件来发送这个错误。这样就能排除那些 404， 401， 403等等的错误。</p>
<p>读取 <code>console.error(err.stack)</code> 事实上并不会像预期那样工作，像 node， chrome 基于 V8 的可以使用 <code>Error.captureStackTrace(this, arguments.callee) </code>的错误构造函数来进行堆栈跟踪。</p>
<pre>
var NotFound = function(msg) {
 Error.call(this);
 Error.captureStackTrace(this, arguments.callee);
 this.message = msg || 'Not Found';
 this.statusCode = 404;
 this.name = "notFound"
}
util.inherits(NotFound, Error);

export.NotFoundError = NotFound;</pre>
<p><strong>当然我们还可以将上面这个创建的抽象错误类型扩展到其他自定义错误中：</strong></p>
<pre>
var notFountError = require('./error').NotFountError;
var UserNotFound = function(msg){
 this.constructor.super_(msg);
}

util.inherits(UserNotFound, notFoundError);</pre>
<p><strong>总结</strong></p>
<p>以上就是Node.js下自定义错误类型的全部内容，希望本文的内容对大家学习或者使用Node.js能有一定的帮助，如果有疑问大家可以留言交流。谢谢大家对的支持。</p>
<p>以上是小编为您精心准备的的内容，在的博客、问答、公众号、人物、课程等栏目也有的相关内容，欢迎继续使用右上角搜索按钮进行搜索node<br />
                    ，                错误处理<br />
                    ，                nodejs错误处理<br />
                                    nodejs捕捉错误<br />
                                    nodejs 自定义错误、js 自定义错误类型、node.js开发实战详解、node modules目录详解、node.js package 详解，以便于您获取更多的相关知识。</p>				<div id="single_bottom"></div>
<script>insertAdIfNeeded();</script>
				<div id="time"><strong>时间：</strong> 2024-02-19 07:35:09</div>
		
		</article>

		<!-- social network share -->

<!-- 		<div id="tags">
            <strong>Tags:</strong> <a href="https://www.iamivan.net/tag/node/" title="node">node</a>, <a href="https://www.iamivan.net/tag/nodejs%e6%8d%95%e6%8d%89%e9%94%99%e8%af%af/" title="nodejs捕捉错误">nodejs捕捉错误</a>, <a href="https://www.iamivan.net/tag/nodejs%e9%94%99%e8%af%af%e5%a4%84%e7%90%86/" title="nodejs错误处理">nodejs错误处理</a>, <a href="https://www.iamivan.net/tag/%e9%94%99%e8%af%af%e5%a4%84%e7%90%86/" title="错误处理">错误处理</a>        </div> -->
	</section>
	
	

		<div id="similar">

		<h3>Node.js下自定义错误类型详解_node.js的相关文章</h3>

								<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/pXK9dQM.html" rel="bookmark">node模块机制与异步处理详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				1.模块机制 commonJS模块机制出现的目的是为了构建js在web服务器,桌面程序,浏览器等方面形成生态系统.而node js就是这种规范的一种实现,用requird来引入其他文件,同样,npm也遵循了commonJS定义的包规范,从而形成了一套完整的生态系统. 模块定义并导出 例如有如下一个名为circle.js的文件 exports.getName = function(name) { return name } 模块载入 var circle = require('/circle.js			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/zem5yAz.html" rel="bookmark">node&period;js中的事件处理机制详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				EventEmitter类 在Node.js的用于实现各种事件处理的event模块中,定义了一个EventEmitter类.所有可能触发事件的对象都是一个集成了EventEmitter类的子类的实例对象,在Node.js中,为EventEmitter类定义了许多方法,所有与对象的事件处理函数的绑定及解除相关的处理均依靠这些方法的调用来执行. EventEmitter类的各种方法 event:代表事件名 listener:代表事件处理函数 中括号内的参数代表该参数为可选参数 方法名与参数 描述 a			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/Mv5edab.html" rel="bookmark">Node&period;js Streams文件读写操作详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				Node.js 天生异步和事件驱动,非常适合处理 I/O 相关的任务.如果你在处理应用中 I/O 相关的操作,你可以利用 Node.js 中的流(stream).因此,我们先具体看看流,理解一下它们是怎么简化 I/O 操作的吧.  流是什么流是 unix 管道,让你可以很容易地从数据源读取数据,然后流向另一个目的地. 简单来说,流不是什么特别的东西,它只是一个实现了一些方法的 EventEmitter .根据它实现的方法,流可以变成可读流(Readable),可写流(Writable),或者双向			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/z7QdOXM.html" rel="bookmark">Node&period;js中的事件驱动编程详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				在传统程编程模里,I/O操作就像一个普通的本地函数调用:在函数执行完之前程序被堵塞,无法继续运行.堵塞I/O起源于早先的时间片模型,这种模型下每个进程就像一个独立的人,目的是将每个人区分开,而且每个人在同一时刻通常只能做一件事,必须等待前面的事做完才能决定下一件事做什么.但是这种在计算机网络和Internet上被广泛使用的&quot;一个用户,一个进程&quot;的模型伸缩性很差.管理多个进程时,会耗费很多内存,上下文切换也会占用大量资源,这些对操作系统是个很大的负担,而且随着进程数的递增,会导致系统性能			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/MyKj15z.html" rel="bookmark">Node&period;js开启Https的实践详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				一.首先要去腾讯云申请 申请成功后,你直接下载证书就可以用了. 二.配置nginx 在/etc/nginx/conf.d/下加入你的域名配置比如xxx.com.conf,内容如下 server { listen 80; listen 443 ssl; server_name www.xxx.com; ssl_certificate /etc/nginx/ssl/www.xxx.com_cert.crt; ssl_certificate_key /etc/nginx/ssl/www.xxx.com			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/MygKdlz.html" rel="bookmark">Node&period;js&plus;Express配置入门教程详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				Node.js是一个Javascript运行环境(runtime).实际上它是对Google V8引擎进行了封装.V8引 擎执行Javascript的速度非常快,性能非常好.Node.js对一些特殊用例进行了优化,提供了替代的API,使得V8在非浏览器环境下运行得更好.Node.js是一个基于Chrome JavaScript运行时建立的平台, 用于方便地搭建响应速度快.易于扩展的网络应用.Node.js 使用事件驱动, 非阻塞I/O 模型而得以轻量和高效,非常适合在分布式设备上运行的数据密集型			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/b3ZYNAz.html" rel="bookmark">node&period;js中的require使用详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				代码注释里已经描述的非常的清晰,这里就不多废话了,直接奉上代码: 复制代码 代码如下: /*在node中,可以使用require()函数来加载模块.  * require函数使用一个参数,参数值可以带有完整路径的模块的文件名,也可以为模块名.当使用node中提供的模块时,在require函数中只需要指定模块名即可.  * */ //建立一个页面2.js;代码如下 var name=&quot;思思博士&quot;; exports.name=name; //建立一个页面1.js;代码如下 var two=			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/MlmLvNp.html" rel="bookmark">nodejs下打包模块archiver详解&lowbar;node&period;js</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				archiver是一个在nodejs中能跨平台实现打包功能的模块,可以打zip和tar包,是一个比较好用的三方模块. 使用前先安装archiver模块. 复制代码 代码如下: npm install archiver 建立一段代码 复制代码 代码如下: var archiver = require('archiver'); var fs = require('fs'); //被打包文件 var files = [   'files/001.png',   'files/002.png'   ];			</div>
		</article>
	</section>
				<section>
		<header>
			<h2 class="title">
                <a href="https://www.iamivan.net/a/z4wnAjp.html" rel="bookmark">Swift类型创建之自定义一个类型详解</a>
			</h2>
		</header>
		<article class="clearfix">
									<div class="summary">
				  这篇文章主要介绍了Swift类型创建之自定义一个类型详解,本文讲解了自定义原型.实现默认值.支持基本布尔型初始化.支持Bool类型判断.支持兼容各们各派的类型.完善OCBool的布尔基因体系等内容,需要的朋友可以参考下 小伙伴们,Swift中的Bool类型有着非常重要的语法功能,并支撑起了整个Swift体系中的逻辑判断体系,经过老码的研究和学习, Bool类型本身其实是对基础Boolean类型封装,小伙伴们可能咬着手指头问老码,怎么一会Bool类型,一会Boolean类型,其区别在于,前者是			</div>
		</article>
	</section>
	
	</div><!-- /related -->
	


</div>
<!-- /main -->


<aside class="col-md-4">



	<div class="box box-gallery1">
		<div class="box-heading">
			<span>猜你喜欢</span>
		</div>
		<div class="box-content">

									<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/xpnKOOz.html" rel="bookmark" class="title">java中并不是任意多个接口都可以实现多实现</a>
					<div>
						interface A{    public abstract void show(); }   interface B{    public abstract int show(); }   pub ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/qMq7nOz.html" rel="bookmark" class="title">反复测试，找到最佳MTU</a>
					<div>
						命令说明: 输入命令&quot;ping –l 1500 –f 192.168.2.53&quot;,这里我们解释一下命令参数的含义 * –l 1500参数:发送一个定长数据包,1500是要测试的包大 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/YbKdkOM.html" rel="bookmark" class="title">完全CSS下拉菜单，只用CSS，纯CSS构筑！</a>
					<div>
						核心提示:纯CSS构筑的下拉导航菜单! 看看CSS代码,要注意认真看,好好研究哦! &lt;style type=&quot;text/css&quot;&gt;.menu {font-family: ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/2MWqZnz.html" rel="bookmark" class="title">让硬盘摆脱五大怪异的骚扰</a>
					<div>
						读取硬盘中的信息或写入数据到硬盘中,几乎是我们每天要做的&quot;必修课&quot;.可是在频繁访问硬盘的过程中,我们时不时地会发现一些怪异的&quot;骚扰&quot;袭向硬盘,在这些怪异&quo ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/OMg578z.html" rel="bookmark" class="title">TNS-12560的一次解决</a>
					<div>
						解决   TNS-12560的一次解决 昨天我们公司客户服务部的一个后台数据库出现TNS-12560问题,他们的WEB维护人员搞了两天没搞定,后来打电话要我去帮他搞.刚开始以为服务器就放在我们公司,我 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/gpkN97M.html" rel="bookmark" class="title">电子商务网站购物产品收藏功能设计分析</a>
					<div>
						 注:这是某命题作文的核心部分,省略的部分内容不影响阅读,欢迎拍砖.探讨. 一.为什么要做     收藏,侧重于针对自己有价值或可能有帮助及方便日后快速整理的资料信息所做的一个动作,一件事情.对于网购 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/bj7m6dM.html" rel="bookmark" class="title">关系数据库系统</a>
					<div>
						关系数据库系统的应用开始于20世纪80年代,到目前为止它已成为最为流行的数据库系统.在关系数据库系统中,其数据库中的数据是基于关系进行逻辑组织的.一个关系数据库是由若干个关系(即二维表格)所组成的.通 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/pPNXGZb.html" rel="bookmark" class="title">破解加密的Asp木马登陆密码</a>
					<div>
						破解目标:破解一经过加密的Asp木马登陆密码.由于木马里没有版本说明,具体也不知道这木马叫什么名. 破解思路:两种,用加密后的密码替换密文和利用密文及加密算法反解出密码. 前者根本算不上真正的破解.如 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/MW1ma7z.html" rel="bookmark" class="title">UVa 11727 Cost Cutting &lpar;water ver&period;&rpar;</a>
					<div>
						11727 - Cost Cutting Time limit: 1.000 seconds http://uva.onlinejudge.org/index.php?option=com_onlin ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/MqLyjeb.html" rel="bookmark" class="title">在Struts 2中使用JSON插件</a>
					<div>
						JSON插件提供了一种名为json的ResultType,一旦为某个Action指定了一个类型为json的Result,则该Result无需映射到任何视图资源.因为JSON插件会负责将Action里的 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/MY2Yvlp.html" rel="bookmark" class="title">sql查询重复记录、删除重复记录方法大全</a>
					<div>
						查找所有重复标题的记录: ? 1 SELECT * FROM t_info a WHERE ((SELECT COUNT(*) FROM t_info WHERE Title = a.Title) & ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/pXBynWb.html" rel="bookmark" class="title">PS鼠绘粉色调古代清新美女</a>
					<div>
						教程向朋友介绍利用PS鼠绘粉色调古代清新美女,教程只是简单的讲解制作过程,所以要求由一定鼠绘基础的朋友学习.好了我们先看看原图和最终效果图的对比:   最终效果 下面是制作步骤: 一.打开原图,把背景 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/zGj4llp.html" rel="bookmark" class="title">Photoshop制作散发蓝色颗粒的的岩石字</a>
					<div>
						  作者制作岩石字的方法非常不错.过程:直接使用山岩素材,截取局部按文字轮廓摆放,边缘部分用橡皮或蒙版处理自然,然后调色并增加一些装饰即可. 最终效果 1.创建一个新的文档大小的1440 px * 7 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/pd6j2db.html" rel="bookmark" class="title">Windows8缩略图显示错乱如何恢复？</a>
					<div>
						  适用范围: Windows 8 消费者预览版 知识点分析: 在 Windows 8 系统中浏览图片或视频文件时.有时图标,缩略图会无法正常显示,通常这样的情况若不是中毒了,就是相关缓存文件出了问题 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/Mq8o9ab.html" rel="bookmark" class="title">win7 ghost 纯净版系统限制（禁用）IE浏览器中的保存功能的方法</a>
					<div>
						  1.按&quot;WIN+R&quot;打开&quot;运行&quot;窗口,输入&quot;gpedit.msc&quot;命令后回车打开&quot;组策略编辑器&quot;. 2.在&quot ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/pXjVvLb.html" rel="bookmark" class="title">win7开机黑屏只有鼠标解决方法</a>
					<div>
						  1.同时按下键盘Ctrl+Alt+Del(当然在此步骤前,首先要保证电脑连上了键盘),在列表中选择&quot;启动任务管理器&quot;,这是会弹出&quot;任务管理器&quot;,用鼠标点击左 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/bQNRgoM.html" rel="bookmark" class="title">如何利用win7架构局域网络</a>
					<div>
						  无论是在工作还是学习的过程中,架构相关的局域网络都可以帮助计算机用户可以更好的进行资源共享.那么在win7镜像操作系统的环境中,应该要如何架构相关的局域网络呢?需要考虑那几点注意事项呢? 1.网络 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/p5orQDb.html" rel="bookmark" class="title">win7 64位旗舰版系统中PPT放映时显示备注的设置技巧</a>
					<div>
						  1.win7系统中设置显示属性 1)首先鼠标在桌面空白处右击选择&quot;屏幕分辨率&quot;,在点击地址栏中的&quot;连接到投影仪&quot;,然后选择扩展; 2)然后选中进入屏幕分辨率 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/M1E065M.html" rel="bookmark" class="title">XP系统不能访问局域网其他电脑</a>
					<div>
						  在XP系统组建局域网后,在工作站的&quot;网上邻居&quot;中查看服务器的名称,但双击后却不能看到共享内容,并提示&quot;无权查看&quot;. 首先在工作站看到了服务器的名称,这代表了 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/zZd30qM.html" rel="bookmark" class="title">sendBroadcastAsUser&mdash;&mdash;Calling a method in the system process without a qualified user</a>
					<div>
						4.2中Android加入了多用户  改换这几种调用方式  public void startActivityAsUser(Intent intent, UserHandle user); publi ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/Mq8PVeb.html" rel="bookmark" class="title">Java多线程知识小抄集&lpar;一&rpar;</a>
					<div>
						本文主要整理博主遇到的Java多线程的相关知识点,适合速记,故命名为&quot;小抄集&quot;.本文没有特别重点,每一项针对一个多线程知识做一个概要性总结,也有一些会带一点例子,习题方便理解和记忆 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/MWXOymp.html" rel="bookmark" class="title">平板-关于eclipse识别不出设备问题</a>
					<div>
						问题描述 关于eclipse识别不出设备问题 我用eclipse开发android 的,我重装了一次系统,并重装了eclipse(我的eclipse是绿色版的,可以直接解压使用),我不管是手机或是平板 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/p5Nr3Rz.html" rel="bookmark" class="title">服务器-安卓有关handler问题</a>
					<div>
						问题描述 安卓有关handler问题 现在的安卓项目与服务器交互数据都是用的handler吗? 小的demo讲解有吗 解决方案 与服务器交互的时候一般选择**异步任务**. 解决方案二: 安卓hand ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/p5Nvrmz.html" rel="bookmark" class="title">多表查询-关于数据表之间的关系</a>
					<div>
						问题描述 关于数据表之间的关系 对于多表查询的情况,数据库里定义了关系,在应用程序写sql语句时还需要描述表之间的关系吗?两者是否可以只选其一? 解决方案 多表关联一般通过inner join.lef ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/p5NB2mz.html" rel="bookmark" class="title">告别繁琐&excl; Vista下快捷方式网络连接管理</a>
					<div>
						有许 多人抱怨说http://www.aliyun.com/zixun/aggregation/15470.html&quot;&gt;Vista中进入网络连接管理非常麻烦,没错,如果不熟悉的用户根本 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/bBZalOb.html" rel="bookmark" class="title">gcc-&period;h文件里定义了一个类，怎么链接到so文件里？</a>
					<div>
						问题描述 .h文件里定义了一个类,怎么链接到so文件里? A.h里定义了class B C.cpp里include A.h并且引用了B类,声明B类B b: G++ C.cpp -o X.so 为什么用 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/pkeL65b.html" rel="bookmark" class="title">mysql的数据恢复</a>
					<div>
						数据库数据被误删除是经常看到的事情,数据的恢复也就自然成为了DBA很重要的一门基本功夫,比较笨拙的办法是拉出历史的备份到另外的一台机器恢复出来,但是这种方法如果数据量比较大的话,往往会耗费较长的时间, ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/bK5Ljdp.html" rel="bookmark" class="title">麻烦各位大神帮帮忙！C&num;解析xml实现对应数据库中的字段&comma;导入excel数据到orcel数据库</a>
					<div>
						问题描述 麻烦各位大神帮帮忙!C#解析xml实现对应数据库中的字段,导入excel数据到orcel数据库 我现在已经写好了导入数据库了,可是字段是定死的,预防有时候excel表格有变化,方便修改,所以 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/pnRZJrp.html" rel="bookmark" class="title">&period;net开源了，学&period;net还是学java呢 ？</a>
					<div>
						问题描述 查了一晚上资料,到底是学java还.net呢?先说说我的目的,我想自己开发web或APP的后台,当然,其他的地方也可能用的上,只是我目前还没想到.我首先想的是自己开发和维护APP后台.看了很 ...					</div>
				</div>
			</div>
						<div class="item clearfix">
										<div class="info"  style="max-width: 100%;" >
					<a href="https://www.iamivan.net/a/p8Yde4z.html" rel="bookmark" class="title">目标：过滤掉其他ip的请求包</a>
					<div>
						问题描述 我们学校整体是个网吧,选课的时候有点困难.我想同过一定的方法来过滤掉除自己ip以外的其他ip对服务器的请求包,大牛们能不能赐教呀! 解决方案 解决方案二:该回复于2012-02-23 14: ...					</div>
				</div>
			</div>
			
		</div>
	</div>

	<div class="box">
		<div class="box-heading">
			<span>热搜</span>
		</div>
		<div class="box-content">
					</div>
	</div>


</aside>
      </div>
    </div>
    <!-- /.container -->

    <div id="copyright">
      <div class="pull-left">
        &#169; 2024 iVAN        | info#iamivan.net        | 11 q. 0.029 s.
      </div>

    </div>

  </div><!--/.wrapper -->


  <!-- <script src="/assets/js/jquery.js"></script>
  <script src="/assets/js/bootstrap.min.js"></script> -->
  <div style=" display: none ";>
  </div>

<script src="/assets/js/echo.js"></script>
<script>
    echo.init({
      offset: 100,
      throttle: 250,
      unload: false,
      callback: function (element, op) {
        console.log(element, 'has been', op + 'ed')
      }
    });
    </script>
</body>
</html>
